Use Case:  Browse for content submitted for review and publication
==================================================================

Actor
-----

  - Reviewer

Overview
--------

  The Reviewer's job is to enforce the site's policies with respect
  to the quality and appropriateness of content published by Content
  Creators.

Assumptions
-----------

  - Reviewer has logged into the CMF (see "Login to the
    Site":LoginAsMember).

  - Content has been submitted for review (see "Submit content for
    publication":SubmitContentForPublication).

Procedure
---------

  1.  From the actions box, select the 'Pending review (x)' link.

  2.  Browse the list of content which has been submitted for
      Publication.
